@@ -17,17 +17,17 @@
 use crate::{
     templates::{
         bls12::{Bls12Parameters, TwistType},
-        short_weierstrass::short_weierstrass_jacobian::{GroupAffine, GroupProjective},
+        short_weierstrass_jacobian::{Affine, Projective},
     },
-    traits::{AffineCurve, SWModelParameters},
+    traits::{AffineCurve, ShortWeierstrassParameters},
 };
 use snarkvm_fields::{Field, Fp2, One, Zero};
-use snarkvm_utilities::{bititerator::BitIteratorBE, bytes::ToBytes, errors::SerializationError, serialize::*};
+use snarkvm_utilities::{bititerator::BitIteratorBE, errors::SerializationError, serialize::*, ToBytes};
 
 use std::io::{Result as IoResult, Write};
 
-pub type G2Affine<P> = GroupAffine<<P as Bls12Parameters>::G2Parameters>;
-pub type G2Projective<P> = GroupProjective<<P as Bls12Parameters>::G2Parameters>;
+pub type G2Affine<P> = Affine<<P as Bls12Parameters>::G2Parameters>;
+pub type G2Projective<P> = Projective<<P as Bls12Parameters>::G2Parameters>;
 type CoeffTriplet<T> = (Fp2<T>, Fp2<T>, Fp2<T>);
 
 #[derive(Derivative, CanonicalSerialize, CanonicalDeserialize)]
@@ -63,13 +63,13 @@ impl<P: Bls12Parameters> Default for G2Prepared<P> {
 }
 
 impl<P: Bls12Parameters> ToBytes for G2Prepared<P> {
-    fn write<W: Write>(&self, mut writer: W) -> IoResult<()> {
+    fn write_le<W: Write>(&self, mut writer: W) -> IoResult<()> {
         for coeff in &self.ell_coeffs {
-            coeff.0.write(&mut writer)?;
-            coeff.1.write(&mut writer)?;
-            coeff.2.write(&mut writer)?;
+            coeff.0.write_le(&mut writer)?;
+            coeff.1.write_le(&mut writer)?;
+            coeff.2.write_le(&mut writer)?;
         }
-        self.infinity.write(writer)
+        self.infinity.write_le(writer)
     }
 }
 
