@@ -16,7 +16,8 @@
 
 pub mod bls12;
 pub mod bw6;
-pub mod short_weierstrass;
+pub mod short_weierstrass_jacobian;
+pub mod short_weierstrass_projective;
 pub mod to_field_vec;
 pub mod twisted_edwards_extended;
 
